#[repr(i8)]pub enum OrganizationUserStatusType {
Revoked = -1,
Invited = 0,
Accepted = 1,
Confirmed = 2,
}Expand description
The membership status of a user within an organization.
Variants
Revoked = -1
The user’s access has been revoked. This may occur at any time from any other status.
Invited = 0
The user has been invited but has not yet accepted.
Accepted = 1
The user has accepted the invitation but has not yet been confirmed by an admin.
Confirmed = 2
The user has been confirmed by an admin and has full access.