#[repr(u8)]pub enum ProviderType {
Msp = 0,
Reseller = 1,
BusinessUnit = 2,
}Expand description
The type of provider.
Variants
Msp = 0
Managed Service Provider - sells and manages its clients’ Bitwarden organizations.
Reseller = 1
Reseller partner - sells Bitwarden to its clients but does not have any administrative access.
BusinessUnit = 2
Business unit provider - used to manage multiple organizations which form part of a single large enterprise.