pub struct Permissions {
pub access_event_logs: bool,
pub access_import_export: bool,
pub access_reports: bool,
pub create_new_collections: bool,
pub edit_any_collection: bool,
pub delete_any_collection: bool,
pub manage_groups: bool,
pub manage_sso: bool,
pub manage_policies: bool,
pub manage_users: bool,
pub manage_reset_password: bool,
pub manage_scim: bool,
}Expand description
Custom administrative permissions for an organization member with the
OrganizationUserType::Custom role.
Fields
access_event_logs: boolCan view the organization’s event logs.
access_import_export: boolCan import and export organization vault data.
access_reports: boolCan access organization reports.
create_new_collections: boolCan create new collections.
edit_any_collection: boolCan edit any collection, including those they are not assigned to.
delete_any_collection: boolCan delete any collection, including those they are not assigned to.
manage_groups: boolCan manage groups within the organization.
manage_sso: boolCan manage SSO configuration.
manage_policies: boolCan manage organization policies.
manage_users: boolCan manage organization members.
manage_reset_password: boolCan manage the account recovery (password reset) feature.
manage_scim: boolCan manage SCIM (System for Cross-domain Identity Management) configuration.