pub struct ProfileOrganization {Show 61 fields
pub id: Uuid,
pub name: String,
pub status: OrganizationUserStatusType,
pub type: OrganizationUserType,
pub enabled: bool,
pub use_policies: bool,
pub use_groups: bool,
pub use_directory: bool,
pub use_events: bool,
pub use_totp: bool,
pub use_2fa: bool,
pub use_api: bool,
pub use_sso: bool,
pub use_organization_domains: bool,
pub use_key_connector: bool,
pub use_scim: bool,
pub use_custom_permissions: bool,
pub use_reset_password: bool,
pub use_secrets_manager: bool,
pub use_password_manager: bool,
pub use_activate_autofill_policy: bool,
pub use_automatic_user_confirmation: bool,
pub self_host: bool,
pub users_get_premium: bool,
pub seats: u32,
pub max_collections: u32,
pub max_storage_gb: Option<u32>,
pub sso_bound: bool,
pub identifier: Option<String>,
pub permissions: Permissions,
pub reset_password_enrolled: bool,
pub user_id: Option<Uuid>,
pub organization_user_id: Option<Uuid>,
pub has_public_and_private_keys: bool,
pub provider_id: Option<Uuid>,
pub provider_name: Option<String>,
pub provider_type: Option<ProviderType>,
pub is_provider_user: bool,
pub is_member: bool,
pub family_sponsorship_friendly_name: Option<String>,
pub family_sponsorship_available: bool,
pub product_tier_type: ProductTierType,
pub key_connector_enabled: bool,
pub key_connector_url: Option<String>,
pub family_sponsorship_last_sync_date: Option<DateTime<Utc>>,
pub family_sponsorship_valid_until: Option<DateTime<Utc>>,
pub family_sponsorship_to_delete: Option<bool>,
pub access_secrets_manager: bool,
pub limit_collection_creation: bool,
pub limit_collection_deletion: bool,
pub limit_item_deletion: bool,
pub allow_admin_access_to_all_collection_items: bool,
pub user_is_managed_by_organization: bool,
pub use_access_intelligence: bool,
pub use_admin_sponsored_families: bool,
pub use_disable_sm_ads_for_users: bool,
pub is_admin_initiated: bool,
pub sso_enabled: bool,
pub sso_member_decryption_type: Option<MemberDecryptionType>,
pub use_phishing_blocker: bool,
pub use_my_items: bool,
}Expand description
Organization membership details from the user’s profile sync.
Contains the full set of entitlements, plan features, and metadata for a single organization that the current user belongs to.
Fields
id: UuidUnique identifier for the organization.
name: StringDisplay name of the organization.
status: OrganizationUserStatusTypeThe user’s membership status in the organization.
type: OrganizationUserTypeThe user’s role in the organization.
enabled: boolWhether the organization is currently enabled.
use_policies: boolWhether the organization has access to policies features.
use_groups: boolWhether the organization has access to groups features.
use_directory: boolWhether the organization has access to directory sync features.
use_events: boolWhether the organization has access to event logging features.
use_totp: boolWhether the organization can enforce TOTP for members.
use_2fa: boolWhether the organization has access to two-factor authentication features.
use_api: boolWhether the organization has access to the Bitwarden Public API.
use_sso: boolWhether the organization has access to SSO features.
use_organization_domains: boolWhether the organization can manage verified domains.
use_key_connector: boolWhether the organization uses Key Connector for decryption.
use_scim: boolWhether the organization has access to SCIM provisioning.
use_custom_permissions: boolWhether the organization can use the OrganizationUserType::Custom role.
use_reset_password: boolWhether the organization has access to the account recovery (admin password reset) feature.
use_secrets_manager: boolWhether the organization has access to Secrets Manager.
use_password_manager: boolWhether the organization has access to Password Manager.
use_activate_autofill_policy: boolWhether the organization can use the activate autofill policy.
use_automatic_user_confirmation: boolWhether the organization can automatically confirm new members without manual admin approval.
self_host: boolWhether the organization can create a license file for a self-hosted instance.
Whether organization members receive premium features.
seats: u32The number of licensed seats for the organization.
max_collections: u32The maximum number of collections the organization can create.
max_storage_gb: Option<u32>The maximum encrypted storage in gigabytes, if limited.
sso_bound: boolWhether the current user’s account is bound to this organization via SSO.
identifier: Option<String>The organization’s SSO identifier.
permissions: PermissionsThe current user’s custom permissions, relevant when OrganizationUserType::Custom is
the user’s type.
reset_password_enrolled: boolWhether the current user is enrolled in account recovery for this organization.
user_id: Option<Uuid>The current user’s personal user ID.
organization_user_id: Option<Uuid>The current user’s organization membership ID.
has_public_and_private_keys: boolWhether the organization has both a public and private key configured.
provider_id: Option<Uuid>The ID of the provider managing this organization, if any.
provider_name: Option<String>The name of the provider managing this organization, if any.
provider_type: Option<ProviderType>The type of provider managing this organization, if any.
is_provider_user: boolWhether the current user accesses this organization through a provider.
is_member: boolWhether the current user is a direct member of this organization (as opposed to provider-only access).
family_sponsorship_friendly_name: Option<String>The friendly name of a pending families sponsorship, if any.
family_sponsorship_available: boolWhether the organization can sponsor a families plan for the current user.
product_tier_type: ProductTierTypeThe subscription tier of the organization.
key_connector_enabled: boolWhether Key Connector is enabled for this organization.
key_connector_url: Option<String>The URL of the Key Connector service, if enabled.
family_sponsorship_last_sync_date: Option<DateTime<Utc>>The date the families sponsorship was last synced, if applicable.
family_sponsorship_valid_until: Option<DateTime<Utc>>The date the families sponsorship expires, if applicable.
family_sponsorship_to_delete: Option<bool>Whether the families sponsorship is scheduled for deletion.
access_secrets_manager: boolWhether the current user has access to Secrets Manager for this organization.
limit_collection_creation: boolWhether collection creation is restricted to owners and admins only.
When false, any member can create collections and automatically receives manage
permissions over collections they create.
limit_collection_deletion: boolWhether collection deletion is restricted to owners and admins only.
When true, regular users cannot delete collections that they manage.
limit_item_deletion: boolWhether item deletion is restricted to members with the Manage collection permission.
When false, members with Edit permission can also delete items within their collections.
allow_admin_access_to_all_collection_items: boolWhether owners and admins have implicit manage permissions over all collections.
When true, owners and admins can alter items, groups, and permissions across all
collections without requiring explicit collection assignments.
When false, admins can only access collections where they have been explicitly assigned.
user_is_managed_by_organization: boolWhether the current user’s account is managed by this organization.
use_access_intelligence: boolWhether the organization has access to Access Intelligence features.
use_admin_sponsored_families: boolWhether the organization can sponsor families plans for members (Families For Enterprises).
use_disable_sm_ads_for_users: boolWhether Secrets Manager ads are disabled for users.
is_admin_initiated: boolWhether the organization’s Families For Enterprises sponsorship was initiated by an admin.
sso_enabled: boolWhether SSO login is currently enabled for this organization.
sso_member_decryption_type: Option<MemberDecryptionType>The decryption type used for SSO members, if SSO is enabled.
use_phishing_blocker: boolWhether the organization has access to phishing blocker features.
use_my_items: boolWhether the organization has access to the My Items collection feature. This allows users to store personal items in the organization vault if the Centralize Organization Ownership policy is enabled.